' Dragonfly SyncOpenShutter script 
'
' Will work with the configuration in the manual "DragonflySetup"
'
' (c) Lunatico 2016
'
' Only 2 things you may want to adjust are:
'	- the time alotted for the roof moving, currently at 120 secs
'	- the park sensor level (reading) for parked mount (now at 350, surely need change)
'
' The pulse for the motor is set at 2 secs (2000 milisecs) and should work in any setup
'
' Last, if you want to command the mount to park from this script, go on and read a bit ahead
'
' ANY CHANGE MADE TO THIS FILE IS PROBABLY ALSO NEEDED IN SyncCloseShutter.vbs
'

Option Explicit

' ASCOM Shutter State
const ShutterStatus_Open = 0		' these values are from the ASCOM standard, cannot be changed!
const ShutterStatus_Closed = 1
const ShutterStatus_Opening = 2
const ShutterStatus_Closing = 3
const ShutterStatus_Error = 4

' Own constants
' define your own constants here

const Sens_OpenRoof = 1
const Sens_ClosedRoof  = 2
const Sens_Park = 8

const Rel_Roof = 1
const Rel_Mount = 2
const Rel_CCD = 3
const Rel_Lights = 4
const Rel_Focus = 5
const Rel_Fans = 6
const Rel_FlatFoil = 7			' actually we do nothing with the FlatFoil
const Rel_Cover = 8

const Timeout_OpenClose = 120000	' 120 secs time for roof to move
const RoofPulseLenght = 2000		' 2 secs pulse for the roof "button"
const Park_Level = 350			' reading of dist sensor above which mount is parked

' Program section

dim df 
Dim i

set df = CreateObject( "Dragonfly.Help" )

' first of all, to avoid reentries
df.AscomShutterStatus = ShutterStatus_Opening	' opening

' let's show some info in the log window
df.LogShow
df.LogAddLine( "Commanded to open the roof" )
df.LogSetForeColor( &H0FF& )
df.LogSetBold( true )

' check if already open

if ( df.SensorDigRead( Sens_OpenRoof ) ) then			' sensor marks roof as open

	' just for added safety, let's confirm the closed roof sensor is not active
	if ( df.SensorDigRead( Sens_ClosedRoof ) ) then		' closed AND open ?? Problem here
		df.LogAddLine( "Both roof position sensors active!" )
		df.LogSetBold( true )
		df.LogAddLine( "Reporting error and exiting" )
		df.AscomShutterStatus = ShutterStatus_Error	' report the error and quit
		wscript.quit
	end if

	df.AscomShutterStatus = ShutterStatus_Open		' it is already closed
	df.LogAddLine( "Already open!" )
	' nothing else will be done
else
	' so it is not open

	' let's check if the mount is parked

	if ( df.SensorAnRead( Sens_Park ) < Park_Level ) then		' not parked
		df.LogAddLine( "Mount is not parked" )
		df.LogSetBold( true )
		df.LogAddLine( "Reporting error and exiting" )
		df.AscomShutterStatus = ShutterStatus_Error		' error and exit
		wscript.quit						
	end if

'
'	If you want to command your park to park, by using a script, just delete the section above (7 lines of code!)
'	and replace with this one. Change the script (path and name) and maybe tweak the alloted time
'	(20 seconds now)
'
'	We have to power on the mount if we want to move it...
'	
'	df.RelayClose( Rel_Mount )
'	if ( df.SensorAnRead( Sens_Park ) < Park_Level ) then		' not parked, park and wait
'		Set objShell = CreateObject("Wscript.Shell")
'		objShell.Run( "c:\observatorio\scripts\ParkYTrackOff.vbs"),,False ' command the mount to park
'		wscript.sleep( 20000 )					' 20 seconds, adjust
'	end if

'	if ( df.SensorAnRead( Mount_ParkedSensor ) < Park_Level ) then ' not yet parked!!!
'		df.LogAddLine( "Mount failed to park in time" )
'		df.LogSetBold( true )
'		df.LogAddLine( "Reporting error and exiting" )
'		df.AscomShutterStatus = ShutterStatus_Error		' error and exit
'		wscript.quit						
'	end if
'
	' everything ok, let's go
	
	df.LogAddLine( "Opening the roof..." )
	df.AscomShutterStatus = ShutterStatus_Opening		' opening
	call df.RelayPulse( Rel_Roof, RoofPulseLenght )		' let's move the roof

	' let's check a few times if it reaches the open status
	for i = 0 to 10
		wscript.sleep( Timeout_OpenClose / 10 )
		if ( df.SensorDigRead( Sens_OpenRoof ) ) then	' already open!
			' power on things
			df.RelayClose( Rel_Mount )
			df.RelayClose( Rel_CCD )
			df.RelayClose( Rel_Focus )
			df.RelayClose( Rel_Lights )
			df.RelayClose( Rel_Fans )
			df.RelayClose( Rel_Cover )
			df.LogAddLine( "Roof is open now." )
			df.AscomShutterStatus = ShutterStatus_Open
			wscript.quit				
		end if
	next	

	' if we reach here, it means we've had a problem opening the roof
	df.AscomShutterStatus = ShutterStatus_Error		' report the error and quit
	df.LogAddLine( "Error, the roof does not open!" )
	df.LogSetBold( true )

end if

